@@ -1,11 +1,10 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package CPAN::Meta::Prereqs::Diff::Role::Change;
 
-our $VERSION = '0.001002';
+our $VERSION = '0.001003';
 
 # ABSTRACT: A base behavior for prerequisite changes
 
@@ -62,7 +61,7 @@ CPAN::Meta::Prereqs::Diff::Role::Change - A base behavior for prerequisite chang
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 ATTRIBUTES
 
@@ -90,11 +89,11 @@ The depended upon module
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
